==> haskell-wai-app-static-3.1.9-59-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-app-static.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 wai-app-static
version:              3.1.9
visibility:           public
id:                   wai-app-static-3.1.9-GjFnWc91kL4Bn41kT8p4y4
key:                  wai-app-static-3.1.9-GjFnWc91kL4Bn41kT8p4y4
license:              MIT
maintainer:
    Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>

author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/web-application-interface
synopsis:             WAI application for static serving
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-app-static>.

category:             Web, Yesod
abi:                  35f22d00bdeed36084aee16e62ae00fa
exposed:              True
exposed-modules:
    Network.Wai.Application.Static WaiAppStatic.CmdLine
    WaiAppStatic.Listing WaiAppStatic.Storage.Embedded
    WaiAppStatic.Storage.Filesystem WaiAppStatic.Types

hidden-modules:
    Util WaiAppStatic.Storage.Embedded.Runtime
    WaiAppStatic.Storage.Embedded.TH

import-dirs:          /usr/lib/ghc-9.2.8/site-local/wai-app-static-3.1.9
library-dirs:         /usr/lib/ghc-9.2.8/site-local/wai-app-static-3.1.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-app-static
hs-libraries:         HSwai-app-static-3.1.9-GjFnWc91kL4Bn41kT8p4y4
depends:
    base-4.16.4.0 blaze-html-0.9.2.0-GaSrKu6gylZIYHIkWm02Ci
    blaze-markup-0.8.3.0-EKP12U2bGeIvH38eojwCH bytestring-0.11.4.0
    containers-0.6.5.1 crypton-0.34-KGQpVV0vKKZ7XKEhLuSgPQ
    directory-1.3.6.2 file-embed-0.0.15.0-4hNEx1vJ7JTC58fR03LKND
    filepath-1.4.2.2 http-date-0.0.11-GMfuwofWnRwJ6wlihLatSA
    http-types-0.12.4-EUtXhu021ZKEzVhlnug85Q
    memory-0.18.0-Hvum6HaH78UJG59LYyNLK1
    mime-types-0.1.2.0-4X5b6Sz1aAM6TugVqfWYtQ
    old-locale-1.0.0.7-DSFeUNZwxUU2YUIlh1bsq7
    optparse-applicative-0.17.1.0-9B5O8ePYjUG8evKtX1T4ou
    template-haskell-2.18.0.0 text-1.2.5.0 time-1.11.1.1
    transformers-0.5.6.2 unix-compat-0.7.2-40MYb49W9WGJRhC6EVFLHp
    unordered-containers-0.2.20-DtI6Ump4gwL4XOoZ2vYwmp
    wai-3.2.4-Jk3PC0rxUdX8PQLGr3R9HH
    wai-extra-3.1.15-ImMQYg1NpEzrzu991R0Xh
    warp-3.3.30-BOdgvIaqH54GIfnpgbETx8
    zlib-0.6.3.0-3964NViQXyCEPE6a3KJUdx

haddock-interfaces:
    /usr/share/doc/haskell-wai-app-static/html/wai-app-static.haddock

haddock-html:         /usr/share/doc/haskell-wai-app-static/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-app-static-3.1.9-60-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-app-static.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 wai-app-static
version:              3.1.9
visibility:           public
id:                   wai-app-static-3.1.9-CpHighAc8wTE3qSFMuPWCz
key:                  wai-app-static-3.1.9-CpHighAc8wTE3qSFMuPWCz
license:              MIT
maintainer:
    Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>

author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/web-application-interface
synopsis:             WAI application for static serving
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-app-static>.

category:             Web, Yesod
abi:                  48479ec4f877e95490fb8c7d13200803
exposed:              True
exposed-modules:
    Network.Wai.Application.Static WaiAppStatic.CmdLine
    WaiAppStatic.Listing WaiAppStatic.Storage.Embedded
    WaiAppStatic.Storage.Filesystem WaiAppStatic.Types

hidden-modules:
    Util WaiAppStatic.Storage.Embedded.Runtime
    WaiAppStatic.Storage.Embedded.TH

import-dirs:          /usr/lib/ghc-9.2.8/site-local/wai-app-static-3.1.9
library-dirs:         /usr/lib/ghc-9.2.8/site-local/wai-app-static-3.1.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-app-static
hs-libraries:         HSwai-app-static-3.1.9-CpHighAc8wTE3qSFMuPWCz
depends:
    base-4.16.4.0 blaze-html-0.9.2.0-GaSrKu6gylZIYHIkWm02Ci
    blaze-markup-0.8.3.0-EKP12U2bGeIvH38eojwCH bytestring-0.11.4.0
    containers-0.6.5.1 crypton-0.34-KGQpVV0vKKZ7XKEhLuSgPQ
    directory-1.3.6.2 file-embed-0.0.15.0-4hNEx1vJ7JTC58fR03LKND
    filepath-1.4.2.2 http-date-0.0.11-GMfuwofWnRwJ6wlihLatSA
    http-types-0.12.4-EUtXhu021ZKEzVhlnug85Q
    memory-0.18.0-Hvum6HaH78UJG59LYyNLK1
    mime-types-0.1.2.0-4X5b6Sz1aAM6TugVqfWYtQ
    old-locale-1.0.0.7-DSFeUNZwxUU2YUIlh1bsq7
    optparse-applicative-0.17.1.0-9B5O8ePYjUG8evKtX1T4ou
    template-haskell-2.18.0.0 text-1.2.5.0 time-1.11.1.1
    transformers-0.5.6.2 unix-compat-0.7.3-KGvtZivZQhuJ36VKzTBBhg
    unordered-containers-0.2.20-DtI6Ump4gwL4XOoZ2vYwmp
    wai-3.2.4-Jk3PC0rxUdX8PQLGr3R9HH
    wai-extra-3.1.15-5T65bl2zi3G4W7dm03l5cU
    warp-3.3.30-BOdgvIaqH54GIfnpgbETx8
    zlib-0.6.3.0-3964NViQXyCEPE6a3KJUdx

haddock-interfaces:
    /usr/share/doc/haskell-wai-app-static/html/wai-app-static.haddock

haddock-html:         /usr/share/doc/haskell-wai-app-static/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
